@@ -4,6 +4,7 @@ A python packages to get information form upcoming space launches.
 This code is released under the terms of the MIT license. See the LICENSE
 file for more details.
 """
+from __future__ import annotations
 from typing import List
 
 from aiohttp import ClientSession
@@ -19,14 +20,19 @@ class PyLaunches:
 
     _close_session = False
 
-    def __init__(self, session: ClientSession or None = None) -> None:
+    def __init__(
+        self,
+        session: ClientSession | None = None,
+        token: str = None,
+    ) -> None:
         """Initialize the class."""
         self.session = session
+        self.token = token
         if self.session is None:
             self.session = ClientSession()
             self._close_session = True
 
-    async def __aenter__(self) -> None:
+    async def __aenter__(self) -> PyLaunches:
         """Async enter."""
         return self
 
@@ -42,7 +48,7 @@ class PyLaunches:
     async def upcoming_launches(self) -> List[Launch] or None:
         """Get upcoming launch information."""
         response = LaunchResponse(
-            await call_api(self.session, f"{BASE_URL}/launch/upcoming/")
+            await call_api(self.session, f"{BASE_URL}/launch/upcoming/", self.token)
         )
         if not response.results:
             raise PyLaunchesNoData("No data")
